Index: /issm/trunk/src/m/classes/@model/model.m
===================================================================
--- /issm/trunk/src/m/classes/@model/model.m	(revision 2546)
+++ /issm/trunk/src/m/classes/@model/model.m	(revision 2547)
@@ -258,6 +258,9 @@
 	md.mesh_resolution=NaN;
 
-	%Cielo solver string
+	%PETSc and MATLAB solver string
 	md.solverstring='';
+	md.solver_type='';
+
+	%Analysis and sub_analysis
 	md.analysis_type='';
 	md.sub_analysis_type='';
@@ -290,7 +293,4 @@
 	md.qmu_mass_flux_segments=NaN;
 
-	%Ice solver string
-	md.solver_type='';
-
 	%output
 	md=class(md,'model');
Index: /issm/trunk/src/m/classes/@model/setdefaultparameters.m
===================================================================
--- /issm/trunk/src/m/classes/@model/setdefaultparameters.m	(revision 2546)
+++ /issm/trunk/src/m/classes/@model/setdefaultparameters.m	(revision 2547)
@@ -217,5 +217,5 @@
 %the value of plot can be set to 1 if the user wants to see
 %the direction and the updated parameter after each control
-%method iteration (only for cielo serial)
+%method iteration (only for serial)
 md.plot=0;
 
Index: /issm/trunk/src/m/classes/public/collapse.m
===================================================================
--- /issm/trunk/src/m/classes/public/collapse.m	(revision 2546)
+++ /issm/trunk/src/m/classes/public/collapse.m	(revision 2547)
@@ -120,6 +120,2 @@
 %Update mesh type
 md.type='2d';
-
-%Tie in with Cielo if requested
-cieloend;
-end
Index: /issm/trunk/src/m/classes/public/display/displayparallel.m
===================================================================
--- /issm/trunk/src/m/classes/public/display/displayparallel.m	(revision 2546)
+++ /issm/trunk/src/m/classes/public/display/displayparallel.m	(revision 2547)
@@ -20,6 +20,6 @@
 fielddisplay(md,'queue','special queue name on cluster? default is '''' ');
 
-disp(sprintf('\n      ice solver options:'));
+disp(sprintf('\n      Matlab solver options:'));
 fielddisplay(md,'solver_type','solver type for Ice: ''general'', ''lu'' or ''cholesky''');
-disp(sprintf('\n      cielo solver options:'));
+disp(sprintf('\n      PETSc solver options:'));
 fielddisplay(md,'solverstring','solver string for Petsc. See solversetto... routines. Default is mumps');
Index: /issm/trunk/src/m/classes/public/marshall.m
===================================================================
--- /issm/trunk/src/m/classes/public/marshall.m	(revision 2546)
+++ /issm/trunk/src/m/classes/public/marshall.m	(revision 2547)
@@ -1,7 +1,7 @@
 function marshall(md)
-%MARSHALL - output Cielo compatible binary file from @model md, for certain solution type.
+%MARSHALL - output JPL-package compatible binary file from @model md, for certain solution type.
 %
-%   The routine creates a Cielo compatible binary file from @model md
-%   This binary file will be used for parallel runs in cielo.
+%   The routine creates a JPL-package compatible binary file from @model md
+%   This binary file will be used for parallel runs in JPL-package
 %
 %   Usage:
Index: /issm/trunk/src/m/classes/public/process_solve_options.m
===================================================================
--- /issm/trunk/src/m/classes/public/process_solve_options.m	(revision 2546)
+++ /issm/trunk/src/m/classes/public/process_solve_options.m	(revision 2547)
@@ -32,5 +32,5 @@
 %  process qmu arguments
 outoptions.qmudir=getfieldvalue(options,'qmudir','qmu');  % qmudir =['qmu_' datestr(now,'yyyymmdd_HHMMSS')];
-outoptions.qmufile=getfieldvalue(options,'qmufile','qmu');% qmufile cannot be changed unless cielo_ice_script.sh is also changed
+outoptions.qmufile=getfieldvalue(options,'qmufile','qmu');% qmufile cannot be changed unless ????script.sh is also changed
 outoptions.ivar=getfieldvalue(options,'ivar',1);
 outoptions.iresp=getfieldvalue(options,'iresp',1);
Index: /issm/trunk/src/m/solutions/cielo/diagnostic_core_nonlinear.m
===================================================================
--- /issm/trunk/src/m/solutions/cielo/diagnostic_core_nonlinear.m	(revision 2546)
+++ /issm/trunk/src/m/solutions/cielo/diagnostic_core_nonlinear.m	(revision 2547)
@@ -1,4 +1,7 @@
 function [u_g varargout]=diagnostic_core_nonlinear(m,inputs,analysis_type,sub_analysis_type)
-%INPUT function [ru_g varargout]=cielodiagnostic_core_nonlinear(m,inputs)
+%DIAGNOSTIC_CORE_NONLINEAR - core solution of diagnostic non-linear
+%
+%   Usage:
+%      [u_g varargout]=diagnostic_core_nonlinear(m,inputs,analysis_type,sub_analysis_type)
 	
 %   first off! We are going to modify the loads dataset. We need to shield the loads from those changes once we return;
@@ -76,5 +79,5 @@
 	clear soln
 
-	%more output might be needed, when running in cielocontrol.m
+	%more output might be needed, when running in control_core.m
 	nout=max(nargout,1)-1;
 	if nout==2,
Index: /issm/trunk/src/m/utils/Nightly/testsgetfields.m
===================================================================
--- /issm/trunk/src/m/utils/Nightly/testsgetfields.m	(revision 2546)
+++ /issm/trunk/src/m/utils/Nightly/testsgetfields.m	(revision 2547)
@@ -3,5 +3,5 @@
 %
 %   This routine is used by nightly runs (runme.m and updatearchive.m).
-%   for an input analysis 'prognostic', it will output 'cielo'
+%   for an input analysis 'prognostic', it will output 'prognostic.thickness'
 %
 %   Usage:
Index: /issm/trunk/src/m/utils/Nightly/testsgettolerance.m
===================================================================
--- /issm/trunk/src/m/utils/Nightly/testsgettolerance.m	(revision 2546)
+++ /issm/trunk/src/m/utils/Nightly/testsgettolerance.m	(revision 2547)
@@ -6,8 +6,5 @@
 %
 %   Usage:
-%      tolerance=testsgettolerance(md,package,analysis_type,field),
-%
-%   Example:
-%      tolerance=testsgettolerance(md,'cielo','diagnostic','vel'),
+%      tolerance=testsgettolerance(md,sequence,field);
 %
 %   See also: RUNME
@@ -69,5 +66,5 @@
 
 	else
-		error(['testsgettolerance error message: analysis_type '  analysis_type ' not supported yet with package cielo_parallel']);
+		error(['testsgettolerance error message: analysis_type '  analysis_type ' not supported yet with package parallel solution']);
 	end
 end

Index: /issm/trunk/src/m/solutions/dakota/process_qmu_options.m
===================================================================
--- /issm/trunk/src/m/solutions/dakota/process_qmu_options.m	(revision 2546)
+++ /issm/trunk/src/m/solutions/dakota/process_qmu_options.m	(revision 2547)
@@ -19,5 +19,5 @@
 end
 
 %package: is there one? default to ''cielo''
 found=0;
 for i=1:size(options,1),
@@ -28,7 +28,7 @@
 end
 if ~found,
-	disp('recover_qmu_options info message: no ''package'' was provided, defaulting to ''cielo''');
-	options(end+1,:)={'package' 'cielo'};
-	package='cielo';
+	disp('recover_qmu_options info message: no ''package'' was provided, defaulting to ''JPL''');
+	options(end+1,:)={'package' 'JPL'};
+	package='JPL';
 end
 
@@ -73,10 +73,4 @@
 	error(['process_qmu_options error message: sub_analysis_type ' sub_analysis_type ' not supported yet!']);
 end
-if ~(strcmpi(package,'cielo') |  ...
-		strcmpi(package,'ice') |  ...
-		strcmpi(package,'macayeal') ),
-	error(['process_qmu_options error message: package ' package ' not supported yet!']);
-end
-
 
 
@@ -19,5 +19,5 @@
 end
 
-%package: is there one? default to ''cielo''
+%package: is there one? default to ''JPL''
 found=0;
 for i=1:size(options,1),